@@ -25,8 +25,8 @@
 #define FST_fst_h_
 
 #define FST_MAJOR_VERSION 0
-#define FST_MINOR_VERSION 115
-#define FST_MICRO_VERSION 2
+#define FST_MINOR_VERSION 120
+#define FST_MICRO_VERSION 0
 
 #define FST_VERSIONNUM(X, Y, Z)                                         \
         ((X)*10000 + (Y)*1000 + (Z))
@@ -274,7 +274,7 @@ typedef enum {
   FST_EFFECT_CATEGORY(Shell, 10),
   FST_EFFECT_CATEGORY(Generator, 11),
 
-  fst_categoryLast /* last enum */
+  FST_EFFECT_CATEGORY(MaxCount, 12), /* last enum */
 } t_fstEffectCategories;
 
 typedef enum {
@@ -363,10 +363,12 @@ enum {
   FST_CONSTANT_EXPERIMENTAL(MaxShortLabelLen, 8),
   FST_CONSTANT(MaxProgNameLen, 25), // effGetProgramName
 
+  /* JUCE says that MaxParamStrLen is 8, but hosts allow a bit more (24) */
+  FST_CONSTANT(MaxParamStrLen, 8),
+
   /* returned by audioMasterGetAutomationState: */
   FST_FLAG_UNKNOWN(AutomationUnsupported),
 
-
   /* used as t_fstPinProperties.flags */
   FST_FLAG_UNKNOWN(PinIsActive),
   FST_FLAG_UNKNOWN(PinUseSpeaker),
