@@ -418,7 +418,7 @@ static void print_pinproperties(VstPinProperties*vpp) {
   printf("\n");
 }
 
-static char*speakerArrangement2string(size_t type, char*output, size_t length) {
+static char*speakerArrangement2string(int type, char*output, size_t length) {
   output[0]=0;
   switch(type) {
   default:
